Subject: [PATCH 3/3] gnu: mpv: Update to 0.37.0.

From: Zheng Junjie <[email-masked]>
Date: Thu, 14 Dec 2023 00:57:38 +0800

* gnu/packages/video.scm (mpv): Update to 0.37.0.
[build-system]: Switch to meson-build-system.
[arguments]: <#:configure>: Adjust.
<#:phases>: Remove set-up-waf phase.
[native-inputs]: Add python-wrapper.
[inputs]: Add libplacebo, zimg. Remove python-waf.

Change-Id: I0e61761a4d086a1185730f587869c2552b7cacb0
---
 gnu/packages/video.scm | 31 +++++++++++++------------------
 1 file changed, 13 insertions(+), 18 deletions(-)

diff --git a/gnu/packages/video.scm b/gnu/packages/video.scm
index 1f339df517..b0cdb8cda7 100644
--- a/gnu/packages/video.scm
+++ b/gnu/packages/video.scm
@@ -2343,7 +2343,7 @@ (define-public mplayer
 (define-public mpv
   (package
     (name "mpv")
-    (version "0.36.0")
+    (version "0.37.0")
     (source (origin
               (method git-fetch)
               (uri (git-reference
@@ -2351,8 +2351,8 @@ (define-public mpv
                     (commit (string-append "v" version))))
               (file-name (git-file-name name version))
               (sha256
-               (base32 "1ri06h7pv6hrxmxxc618n9hymlgr0gfx38bqq5dcszdgnlashsgk"))))
-    (build-system waf-build-system)
+               (base32 "1xcyfpd543lbmg587wi0mahrz8vhyrlr4432054vp6wsi3s36c4b"))))
+    (build-system meson-build-system)
     (arguments
      (list
       #:phases
@@ -2369,20 +2369,15 @@ (define-public mpv
               ;; and passed as linker flags, but the order in which they are added
               ;; varies.  See <https://github.com/mpv-player/mpv/issues/7855>.
               ;; Set PYTHONHASHSEED as a workaround for deterministic results.
-              (setenv "PYTHONHASHSEED" "1")))
-          (add-before 'configure 'set-up-waf
-            (lambda* (#:key inputs #:allow-other-keys)
-              (copy-file (search-input-file inputs "bin/waf") "waf")
-              (setenv "CC" #$(cc-for-target)))))
+              (setenv "PYTHONHASHSEED" "1"))))
       #:configure-flags
-      #~(list "--enable-libmpv-shared"
-              "--enable-cdda"
-              "--enable-dvdnav"
-              "--disable-build-date")
-      ;; No check function defined.
-      #:tests? #f))
+      #~(list "-Dlibmpv=true"
+              "-Dcdda=enabled"
+              "-Ddvdnav=enabled"
+              "-Dbuild-date=false")))
     (native-inputs
-     (list perl ; for zsh completion file
+     (list python-wrapper
+           perl ; for zsh completion file
            pkg-config python-docutils))
     ;; Missing features: libguess, V4L2.
     (inputs
@@ -2400,6 +2395,7 @@ (define-public mpv
            libdvdread
            libdvdnav
            libjpeg-turbo
+           libplacebo
            libva
            libvdpau
            libx11
@@ -2410,13 +2406,11 @@ (define-public mpv
            libxrandr
            libxscrnsaver
            libxv
            ;; XXX: lua > 5.2 is not currently supported; see
            ;; waftools/checks/custom.py
            lua-5.2
            mesa
            mpg123
            pulseaudio
-           python-waf
            rsound
            shaderc
            vulkan-headers
@@ -2424,6 +2418,7 @@ (define-public mpv
            wayland
            wayland-protocols
            yt-dlp
+           zimg
            zlib))
     (home-page "https://mpv.io/")
     (synopsis "Audio and video player")
@@ -2410,13 +2406,11 @@ (define-public mpv
            libxscrnsaver
            libxv
-           ;; XXX: lua > 5.2 is not currently supported; see
-           ;; waftools/checks/custom.py
+           ;; XXX: lua > 5.2 is not currently supported; see meson.build
            lua-5.2
            mesa
-- 
2.41.0